denoise: denoise

View source: R/utils.R

denoiseR Documentation

denoise

Description

Point density is estimated using a Gaussian mixture model and points in low density regions are considered as noise and removed.

Usage

denoise(points, k = 16, prob = 0.3)

Arguments

points

a data frame with columns x,y,z.

k

integer, number of mixture components for the GMM

prob

probability level in the range [0,1] to identify high density regions

Value

a point set


LOMAR documentation built on Feb. 5, 2026, 5:08 p.m.